module.exports = defineTest({
	description: 'tracks tree-shaking of arguments through simplified conditionals'
});
